==> jboss-3.2.7-src.tar.bz2: jboss-3.2.7-src/testsuite/src/main/org/jboss/test/cmp2/cmrtree/ejb/BBean.java <==
/*
 * JBoss, the OpenSource J2EE webOS
 *
 * Distributable under LGPL license.
 * See terms of license at gnu.org.
 */
package org.jboss.test.cmp2.cmrtree.ejb;

import org.apache.log4j.Category;

import javax.ejb.EntityBean;
import javax.ejb.EntityContext;
import javax.ejb.RemoveException;
import javax.ejb.CreateException;
import java.util.Collection;


/**
 * @ejb.bean
 *    name="B"
 *    type="CMP"
 *    cmp-version="2.x"
 *    view-type="local"
 *    reentrant="false"
 * @ejb.pk generate="true"
 * @ejb.util  generate="physical"
 * @ejb.persistence  table-name="CMRTEEB"
 * @jboss.persistence
 * create-table="true"
 * remove-table="true"
 * @ejb:transaction type="Required"
 * @ jboss.container-configuration name="custom container"
 *
 * @author <a href="mailto:alex@jboss.org">Alexey Loubyansky</a>
 * @version <tt>$Revision: 1.2.2.2 $</tt>
 */
public abstract class BBean
   implements EntityBean
{
   // Attributes -----------------------------------------------
   Category log = Category.getInstance(BBean.class);
   private EntityContext ctx;

   // CMP accessors --------------------------------------------
   /**
    * @ejb.pk-field
    * @ejb.persistent-field
    * @ejb.interface-method
    */
   public abstract int getMajorId();

   public abstract void setMajorId(int id);

   /**
    * @ejb.pk-field
    * @ejb.persistent-field
    * @ejb.interface-method
    */
   public abstract String getMinorId();

   public abstract void setMinorId(String id);

   /**
    * @ejb.persistent-field
    * @ejb.interface-method
    */
   public abstract String getName();

   /**
    * @ejb.interface-method
    */
   public abstract void setName(String id);

   /**
    * @ejb.persistent-field
    * @ejb.interface-method
    */
   public abstract String getAMinorId();
   /**
    * @ejb.interface-method
    */
   public abstract void setAMinorId(String aid);

   /**
    * @ejb.persistent-field
    * @ejb.interface-method
    */
   public abstract String getParentBMinorId();
   /**
    * @ejb.interface-method
    */
   public abstract void setParentBMinorId(String bid);

   /**
    * @ejb.interface-method
    * @ejb.relation name="B-Children"
    *    role-name="B-has-children"
    */
   public abstract Collection getChildren();

   /**
    * @ejb.interface-method
    */
   public abstract void setChildren(Collection c);

   /**
    * @ejb.interface-method
    * @ejb.relation
    *    name="B-Children"
    *    role-name="child-has-Parent"
    *    cascade-delete="true"
    * @jboss.relation
    *    fk-constraint="false"
    *    related-pk-field="majorId"
    *    fk-column="majorId"
    * @jboss.relation
    *    fk-constraint="false"
    *    related-pk-field="minorId"
    *    fk-column="parentBMinorId"
    */
   public abstract BLocal getParent();
   /**
    * @ejb.interface-method
    */
   public abstract void setParent(BLocal a);

   /**
    * @ejb.interface-method
    * @ejb.relation
    *    name="A-B"
    *    role-name="B-has-A"
    *    cascade-delete="true"
    * @jboss.relation
    *    fk-constraint="false"
    *    related-pk-field="majorId"
    *    fk-column="majorId"
    * @jboss.relation
    *    fk-constraint="false"
    *    related-pk-field="minorId"
    *    fk-column="AMinorId"
    */
   public abstract ALocal getA();
   /**
    * @ejb.interface-method
    */
   public abstract void setA(ALocal a);

   /**
    * @ejb.create-method
    * @throws CreateException
    */
   public BPK ejbCreate(int majorId, String minorId, String name)
      throws CreateException
   {
      setMajorId(majorId);
      setMinorId(minorId);
      setName(name);
      return null;
   }

   public void ejbPostCreate(int majorId, String minorId, String name)
   {
   }

   /**
    * @param  ctx The new entityContext value
    */
   public void setEntityContext(EntityContext ctx)
   {
      this.ctx = ctx;
   }

   /**
    * Unset the associated entity context.
    */
   public void unsetEntityContext()
   {
      this.ctx = null;
   }

   public void ejbActivate()
   {
   }

   public void ejbLoad()
   {
   }

   public void ejbPassivate()
   {
   }

   public void ejbRemove() throws RemoveException
   {
   }

   public void ejbStore()
   {
   }
}

==> jboss-4.0.2-src.tar.bz2: jboss-4.0.2-src/testsuite/src/main/org/jboss/test/cmp2/cmrtree/ejb/BBean.java <==
/*
 * JBoss, the OpenSource J2EE webOS
 *
 * Distributable under LGPL license.
 * See terms of license at gnu.org.
 */
package org.jboss.test.cmp2.cmrtree.ejb;

import org.apache.log4j.Category;

import javax.ejb.EntityBean;
import javax.ejb.EntityContext;
import javax.ejb.RemoveException;
import javax.ejb.CreateException;
import java.util.Collection;


/**
 * @ejb.bean
 *    name="B"
 *    type="CMP"
 *    cmp-version="2.x"
 *    view-type="local"
 *    reentrant="false"
 * @ejb.pk generate="true"
 * @ejb.util  generate="physical"
 * @ejb.persistence  table-name="CMRTREEB"
 * @jboss.persistence
 * create-table="true"
 * remove-table="true"
 * @ejb:transaction type="Required"
 * @ jboss.container-configuration name="custom container"
 *
 * @author <a href="mailto:alex@jboss.org">Alexey Loubyansky</a>
 * @version <tt>$Revision: 1.1.2.2 $</tt>
 */
public abstract class BBean
   implements EntityBean
{
   // Attributes -----------------------------------------------
   Category log = Category.getInstance(BBean.class);
   private EntityContext ctx;

   // CMP accessors --------------------------------------------
   /**
    * @ejb.pk-field
    * @ejb.persistent-field
    * @ejb.interface-method
    */
   public abstract int getMajorId();

   public abstract void setMajorId(int id);

   /**
    * @ejb.pk-field
    * @ejb.persistent-field
    * @ejb.interface-method
    */
   public abstract String getMinorId();

   public abstract void setMinorId(String id);

   /**
    * @ejb.persistent-field
    * @ejb.interface-method
    */
   public abstract String getName();

   /**
    * @ejb.interface-method
    */
   public abstract void setName(String id);

   /**
    * @ejb.persistent-field
    * @ejb.interface-method
    */
   public abstract String getAMinorId();
   /**
    * @ejb.interface-method
    */
   public abstract void setAMinorId(String aid);

   /**
    * @ejb.persistent-field
    * @ejb.interface-method
    */
   public abstract String getParentBMinorId();
   /**
    * @ejb.interface-method
    */
   public abstract void setParentBMinorId(String bid);

   /**
    * @ejb.interface-method
    * @ejb.relation name="B-Children"
    *    role-name="B-has-children"
    */
   public abstract Collection getChildren();

   /**
    * @ejb.interface-method
    */
   public abstract void setChildren(Collection c);

   /**
    * @ejb.interface-method
    * @ejb.relation
    *    name="B-Children"
    *    role-name="child-has-Parent"
    *    cascade-delete="true"
    * @jboss.relation
    *    fk-constraint="false"
    *    related-pk-field="majorId"
    *    fk-column="majorId"
    * @jboss.relation
    *    fk-constraint="false"
    *    related-pk-field="minorId"
    *    fk-column="parentBMinorId"
    */
   public abstract BLocal getParent();
   /**
    * @ejb.interface-method
    */
   public abstract void setParent(BLocal a);

   /**
    * @ejb.interface-method
    * @ejb.relation
    *    name="A-B"
    *    role-name="B-has-A"
    *    cascade-delete="true"
    * @jboss.relation
    *    fk-constraint="false"
    *    related-pk-field="majorId"
    *    fk-column="majorId"
    * @jboss.relation
    *    fk-constraint="false"
    *    related-pk-field="minorId"
    *    fk-column="AMinorId"
    */
   public abstract ALocal getA();
   /**
    * @ejb.interface-method
    */
   public abstract void setA(ALocal a);

   /**
    * @ejb.create-method
    * @throws CreateException
    */
   public BPK ejbCreate(int majorId, String minorId, String name)
      throws CreateException
   {
      setMajorId(majorId);
      setMinorId(minorId);
      setName(name);
      return null;
   }

   public void ejbPostCreate(int majorId, String minorId, String name)
   {
   }

   /**
    * @param  ctx The new entityContext value
    */
   public void setEntityContext(EntityContext ctx)
   {
      this.ctx = ctx;
   }

   /**
    * Unset the associated entity context.
    */
   public void unsetEntityContext()
   {
      this.ctx = null;
   }

   public void ejbActivate()
   {
   }

   public void ejbLoad()
   {
   }

   public void ejbPassivate()
   {
   }

   public void ejbRemove() throws RemoveException
   {
   }

   public void ejbStore()
   {
   }
}
